@@ -1,25 +1,51 @@
+#' Change parameters in the control file.
+#' 
+#' A function to take advantage of \code{\link{SS_parlines}} that could be used
+#' to create a series of control files with different parameter values. This is
+#' used by \code{\link{SS_profile}}, but may also be useful for simulation
+#' work.
+#' 
+#' 
+#' @param dir Directory with control file to change.
+#' @param ctlfile Control file name. Default="control.ss_new".
+#' @param newctlfile Name of new control file to be written.
+#' Default="control_modified.ss".
+#' @param linenums Line numbers of control file to be modified. Either this or
+#' the Strings input are needed. Default=NULL.
+#' @param strings Strings (with optional partial matching) indicating which
+#' parameters to be modified. This is an alternative to linenums.  Strings
+#' correspond to the commented parameter names included in control.ss_new, or
+#' whatever is written as comment at the end of the 14 number parameter lines.
+#' Default=NULL.
+#' @param newvals Vector of new parameter values. Default=NULL.
+#' @param repeat.vals If multiple parameter lines match criteria, repeat the
+#' \code{newvals} input for each line
+#' @param estimate Vector of TRUE/FALSE for which changed parameters are to be
+#' estimated. Default=FALSE.
+#' @param verbose More detailed output to command line. Default=TRUE.
+#' @author Ian Taylor
+#' @seealso \code{\link{SS_parlines}}, \code{\link{SS_profile}}
+#' @keywords data manip
+#' @examples
+#' 
+#' \dontrun{
+#' SS_changepars(dir='Y:/ss/SSv3.03a/Simple/',ctlfile='Control.SS_New',
+#'               strings=c('SR_steep','SR_sigmaR'),newvals=c(.35,.6))
+#' # [1] wrote new file to Control_Modified.SS
+#' #    oldvals newvals oldphase newphase     comment
+#' # 1 0.609048    0.35        4       -4  # SR_steep
+#' # 2 0.600000    0.60       -4       -4 # SR_sigmaR
+#' }
+#' 
 SS_changepars <-
 function(
          dir="C:/myfiles/mymodels/myrun/",
          ctlfile="control.ss_new",
          newctlfile="control_modified.ss",
-         linenums=NULL, strings=NULL, newvals=NULL,
+         linenums=NULL, strings=NULL, newvals=NULL, repeat.vals=FALSE,
          estimate=FALSE, verbose=TRUE
          )
 {
-################################################################################
-#
-# SS_changepars November 19, 2008.
-# This function comes with no warranty or guarantee of accuracy
-#
-# Purpose: To change one or more parameter values in the Control file for SSv3
-# Written: Ian Taylor, NWFSC/UW. Ian.Taylor-at-noaa.gov
-# Returns: writes a new control file and returns a table of the changes made
-# Notes:   requires SS_parlines
-#          See users guide for documentation: http://code.google.com/p/r4ss/wiki/
-# Required packages: none
-#
-################################################################################
 
   # read control file
   fullctlfile <- paste(dir,ctlfile,sep="/")
@@ -56,8 +82,15 @@ function(
   oldvals <- oldphase <- newphase <- rep(NA,nvals)
 
   # check inputs
-  if(!is.null(newvals) & length(newvals)!=nvals) stop("'newvals' and either 'linenums' or 'strings' should have the same number of elements")
-  if(!(length(estimate) %in% c(1,nvals))) stop("'estimate' should have 1 element or same number as 'newvals'")
+  if(!is.null(newvals) & length(newvals)!=nvals){
+    if(repeat.vals){
+      newvals <- rep(newvals, nvals)
+    }else{
+      stop("'newvals' and either 'linenums' or 'strings' should have the same number of elements")
+    }
+  }     
+  if(!(length(estimate) %in% c(1,nvals)))
+    stop("'estimate' should have 1 element or same number as 'newvals'")
   if(length(estimate)==1) estimate <- rep(estimate, nvals)
 
   if(is.data.frame(newvals)) newvals <- as.numeric(newvals)
