@@ -1,3 +1,168 @@
+#' plot many quantities related to output from Stock Synthesis
+#' 
+#' Creates a user-chosen set of plots, including biological quantities, time
+#' series, and fits to data.  Plots are sent to R GUI, single PDF file, or
+#' multiple PNG files. This is now just a wrapper which calls on separate
+#' functions to make all the plots.
+#' 
+#' 
+#' @param replist List created by \code{SS_output}
+#' @param plot Plot sets to be created, see list of plots below.  Use to
+#' specify only those plot sets of interest, e.g., c(1,2,5,10). Plots for data
+#' not available in the model run will automatically be skipped, whether called
+#' or not.
+#' @param print Deprecated input for backward compatability, now replaced by
+#' \code{png = TRUE/FALSE}.
+#' @param pdf Send plots to PDF file instead of R GUI?
+#' @param png Send plots to PNG files instead of R GUI?
+#' @param html Run \code{\link{SS_html}} on completion? By default has same
+#' value as \code{png}.
+#' @param printfolder Name of subfolder to create within the working directory
+#' into which any PNG files specified by \code{print} will be saved. By default
+#' the working directory is used with no subfolder.  Default="".
+#' @param dir The directory in which any PNG files requested by \code{print}
+#' are created. By default it will be the same directory that the report file
+#' was read from by the \code{SS_output } function. Default="default".
+#' @param fleets Either the string "all", or a vector of numerical values, like
+#' c(1,3), listing fleets or surveys for which plots should be made. By
+#' default, plots will be made for all fleets and surveys.  Default="all".
+#' @param areas Either the string "all", or a vector of numerical values, like
+#' c(1,3), listing areas for which plots should be made in a multi-area model.
+#' By default, plots will be made for all areas (excepting cases where the
+#' function has not yet been updated for multi-area models). Default="all".
+#' @param fleetnames Either the string "default", or a vector of characters
+#' strings to use for each fleet name. Default="default".
+#' @param fleetcols Either the string "default", or a vector of colors to use
+#' for each fleet.  Default="default".
+#' @param fleetlty Vector of line types used for each fleet in some plots.
+#' Default=1.
+#' @param fleetpch Vector of point types used for each fleet in some plots.
+#' Default=1.
+#' @param lwd Line width for some plots. Default=1.
+#' @param areacols Either the string "default", or a vector of colors to use
+#' for each area. Default="default".
+#' @param areanames Optional vector of names for each area used in titles.
+#' Default="default".
+#' @param verbose Return updates of function progress to the R GUI?  Default=T.
+#' @param uncertainty Include values in plots showing estimates of uncertainty
+#' (requires positive definite hessian in model and \code{covar}=T in
+#' \code{SS_output})?  Default=T.
+#' @param forecastplot Include forecast years in the plots? Obviously requires
+#' forecast options to have been used in the model.  Default=T.
+#' @param datplot Plot the data by itself? This is useful in document
+#' preparation. Setting datplot=F is equivalent to leaving off plots 15 and 16.
+#' Default=F.
+#' @param Natageplot Plot the expected numbers at age bubble plots and mean-age
+#' time series?  Default=T.
+#' @param samplesizeplots Show sample size plots?  Default=T.
+#' @param compresidplots Show residuals for composition plots?
+#' @param sprtarg Specify the F/SPR proxy target. Default=0.4.
+#' @param btarg Target depletion to be used in plots showing depletion. May be
+#' omitted by setting to NA.  Default=0.4.
+#' @param minbthresh Threshold depletion to be used in plots showing depletion.
+#' May be omitted by setting to NA. Default=0.25.
+#' @param pntscalar This scalar defines the maximum bubble size for bubble
+#' plots. This option is still available but a better choice is to use
+#' bub.scale.pearson and bub.scale.dat, which are allow the same scaling
+#' throughout all plots.
+#' @param pntscalar.nums This scalar defines the maximum bubble size for
+#' numbers-at-age and numbers-at-length plots.
+#' @param bub.scale.pearson Character expansion (cex) value for a proportion of
+#' 1.0 in bubble plot of Pearson residuals. Default=1.5.
+#' @param bub.scale.dat Character expansion (cex) value for a proportion of 1.0
+#' in bubble plot of composition data. Default=3.
+#' @param minnbubble This defines the minimum number of years below which blank
+#' years will be added to bubble plots to avoid cropping.  Default=8.
+#' @param aalyear Years to plot multi-panel conditional age-at-length fits for
+#' all length bins; must be in a "c(YYYY,YYYY)" format. Useful for checking the
+#' fit of a dominant year class, critical time period, etc. Default=-1.
+#' @param aalbin The length bin for which multi-panel plots of the fit to
+#' conditional age-at-length data will be produced for all years.  Useful to
+#' see if growth curves are ok, or to see the information on year classes move
+#' through the conditional data. Default=-1.
+#' @param aalresids Plot the full set of conditional age-at-length Pearson
+#' residuals? Default=F.
+#' @param maxneff The maximum value to include on plots of input and effective
+#' sample size. Occasionally a calculation of effective N blows up to very
+#' large numbers, rendering it impossible to observe the relationship for other
+#' data. Default=5000.
+#' @param cohortlines Optional vector of birth years for cohorts for which to
+#' add growth curves to numbers at length bubble plots.  Default=c().
+#' @param smooth Add loess smoother to observed vs. expected index plots and
+#' input vs. effective sample size? Default=T.
+#' @param showsampsize Display sample sizes on composition plots?  Default=T.
+#' @param showeffN Display effective sample sizes on composition plots?
+#' Default=T.
+#' @param sampsizeline show line for input sample sizes on top of conditional
+#' age-at-length plots (TRUE/FALSE, still in development)
+#' @param effNline show line for effective sample sizes on top of conditional
+#' age-at-length plots (TRUE/FALSE, still in development)
+#' @param showlegend Display legends in various plots? Default=T.
+#' @param pwidth Default width of plots printed to files in units of
+#' \code{punits}. Default=7.
+#' @param pheight Default height width of plots printed to files in units of
+#' \code{punits}. Default=7.
+#' @param punits Units for \code{pwidth} and \code{pheight}. Can be "px"
+#' (pixels), "in" (inches), "cm" or "mm". Default="in".
+#' @param ptsize Point size for plotted text in plots printed to files (see
+#' help("png") in R for details). Default=12.
+#' @param res Resolution of plots printed to files. Default=300.
+#' @param cex.main Character expansion parameter for plot titles (not yet
+#' implemented for all plots). Default=1.
+#' @param selexlines Vector controling which lines should be shown on
+#' selectivity plots if the model includes retention. Default=1:5.
+#' @param rows Number of rows to use for single panel plots. Default=1.
+#' @param cols Number of columns to use for single panel plots. Default=1.
+#' @param maxrows Maximum number of rows to for multi-panel plots.  Default=6.
+#' @param maxcols Maximum number of columns for multi-panel plots.  Default=6.
+#' @param maxrows2 Maximum number of rows for conditional age-at-length
+#' multi-panel plots. Default=2.
+#' @param maxcols2 Maximum number of rows for conditional age-at-length
+#' multi-panel plots. Default=4.
+#' @param andrerows Number of rows of Andre's conditional age-at-length plots
+#' within each page. Default=3.
+#' @param tagrows Number of rows for tagging-related plots. Default=3.
+#' @param tagcols Number of columns for tagging-related plots.  Default=3.
+#' @param fixdims Control whether multi-panel plots all have dimensions equal
+#' to maxrows by maxcols, or resized within those limits to fit number of
+#' plots. Default=T.
+#' @param new Open a new window or add to existing plot windows.  Default=T.
+#' @param SSplotDatMargin Size of right-hand margin in data plot (may be too
+#' small if fleet names are long)
+#' @param filenotes Optional vector of character strings to be added to intro
+#' HTML page (if created) with notes about the model.
+#' @param catchasnumbers Is catch input in numbers instead of biomass?
+#' Default=F.
+#' @param catchbars show catch by fleet as barplot instead of stacked polygons
+#' (default=TRUE)
+#' @param legendloc Location for all legends. Default="topleft".
+#' @param minyr First year to show in time-series plots (changes xlim
+#' parameters).
+#' @param maxyr Last year to show in time-series plots (changes xlim
+#' parameters).
+#' @param scalebins Rescale expected and observed proportions in composition
+#' plots by dividing by bin width for models where bins have different widths?
+#' Caution!: May not work correctly in all cases.
+#' @param scalebubbles scale data-only bubbles by sample size, not just
+#' proportion within sample? Default=FALSE.
+#' @param tslabels Either NULL to have default labels for timeseries plots or
+#' a vector of appropriate length (currently 11) with labels for each figure
+#' @param catlabels Either NULL to have default labels for catch plots or
+#' a vector of appropriate length (currently 10) with labels for each figure
+#' @param \dots Additional arguments that will be passed to some subfunctions.
+#' @author Ian Stewart, Ian Taylor
+#' @seealso \code{\link{SS_output}}, \code{\link{SSplotBiology}},
+#' \code{\link{SSplotCatch}}, \code{\link{SSplotComps}},
+#' \code{\link{SSplotDiscard}}, \code{\link{SSplotIndices}},
+#' \code{\link{SSplotMnwt}}, \code{\link{SSplotNumbers}},
+#' \code{\link{SSplotRecdevs}}, \code{\link{SSplotSelex}},
+#' \code{\link{SSplotSpawnrecruit}}, \code{\link{SSplotSPR}},
+#' \code{\link{SSplotTags}}, \code{\link{SSplotTimeseries}},
+#' \code{\link{SSplotYield}}
+#' @references Walters, Hilborn, and Christensen, 2008, Surplus production
+#' dynamics in declining and recovering fish populations. Can. J. Fish. Aquat.
+#' Sci. 65: 2536-2551.
+#' @keywords hplot
 SS_plots <-
   function(
     replist=NULL, plot=1:24, print=NULL, pdf=FALSE, png=FALSE, html=png,
@@ -10,12 +175,14 @@ SS_plots <-
     bub.scale.pearson=1.5,bub.scale.dat=3,pntscalar.nums=2.6,
     minnbubble=8, aalyear=-1, aalbin=-1, aalresids=FALSE, maxneff=5000,
     cohortlines=c(), smooth=TRUE, showsampsize=TRUE, showeffN=TRUE,
+    sampsizeline=FALSE,effNline=FALSE,
     showlegend=TRUE, pwidth=7, pheight=7, punits="in", ptsize=12, res=300,
-    cex.main=1,selexlines=1:5, rows=1, cols=1, maxrows=6, maxcols=6,
-    maxrows2=2, maxcols2=4, tagrows=3, tagcols=3, fixdims=TRUE, new=TRUE,
+    cex.main=1,selexlines=1:6, rows=1, cols=1, maxrows=6, maxcols=6,
+    maxrows2=2, maxcols2=4, andrerows=3, tagrows=3, tagcols=3, fixdims=TRUE,
+    new=TRUE,
     SSplotDatMargin=8, filenotes=NULL, catchasnumbers=NULL, catchbars=TRUE,
     legendloc="topleft", minyr=NULL, maxyr=NULL, scalebins=FALSE,
-    scalebubbles=FALSE,...)
+    scalebubbles=FALSE,tslabels=NULL,catlabels=NULL,...)
 {
   ################################################################################
   #
@@ -120,18 +287,12 @@ SS_plots <-
   # number of plot groups
   nplots <- length(intersect(1:50,plot))
 
-  # make plot window (operating system specific)
-  OS <- "Mac" # don't know the version$os info for Mac
-  if(length(grep("linux",version$os)) > 0) OS <- "Linux"
-  if(length(grep("mingw",version$os)) > 0) OS <- "Windows"
-
+  # make plot window (hopefully no-longer operating system specific)
   if(nplots>0 & !png & !pdf & new){
     ### Note: the following line has been commented out because it was identified
     ###       by Brian Ripley as "against CRAN policies".
     #if(exists(".SavedPlots",where=1)) rm(.SavedPlots,pos=1)
-    if(OS=="Windows") windows(width=pwidth,height=pheight,pointsize=ptsize,record=TRUE)
-    if(OS=="Linux") X11(width=pwidth,height=pheight,pointsize=ptsize)
-    if(OS=="Mac") quartz(width=pwidth,height=pheight,pointsize=ptsize)
+    dev.new(width=pwidth,height=pheight,pointsize=ptsize,record=TRUE)
   }
   if(nplots>0 & !new){
     if(verbose) cat("Adding plots to existing plot window. Plot history not erased.\n")
@@ -181,6 +342,33 @@ SS_plots <-
     par(mar=mar0) # replace margins
   }
 
+if(length(tslabels)==0){
+  tslabels <- c("Total biomass (mt)",        #1
+             "Total biomass (mt) at beginning of season", #2
+             "Summary biomass (mt)",         #3
+             "Summary biomass (mt) at beginning of season", #4
+             "Spawning biomass (mt)",        #5
+             "Spawning depletion",           #6
+             "Spawning output (eggs)",       #7
+             "Age-0 recruits (1,000s)",      #8
+             "Fraction of total Age-0 recruits",  #9
+             "Management target",            #10
+             "Minimum stock size threshold") #11
+  }
+
+if(length(catlabels)==0){
+  catlabels <- c("Harvest rate/Year",     #1
+             "Continuous F",              #2
+             "Landings",                  #3
+             "Total catch",               #4
+             "Predicted Discards",        #5  # should add units
+             "Discard fraction",          #6  # need to add by weight or by length
+             "(mt)",                      #7
+             "(numbers x1000)",           #8
+             "Observed and expected",     #9
+             "aggregated across seasons") #10
+  }
+
   ##########################################
   # Biology plots (mean weight, maturity, fecundity, spawning output)
   # and Time-varying growth
@@ -242,6 +430,7 @@ SS_plots <-
                                minyr=minyr,maxyr=maxyr,
                                pwidth=pwidth, pheight=pheight, punits=punits,
                                ptsize=ptsize, res=res, cex.main=cex.main,
+                               labels=tslabels,
                                plotdir=plotdir)
             if(!is.null(plotinfo)) plotInfoTable <- rbind(plotInfoTable,plotinfo)
           } # end loop over uncertainty or not
@@ -261,11 +450,22 @@ SS_plots <-
                              minyr=minyr,maxyr=maxyr,
                              pwidth=pwidth, pheight=pheight, punits=punits,
                              ptsize=ptsize, res=res, cex.main=cex.main,
+                             labels=tslabels,
                              plotdir=plotdir)
           if(!is.null(plotinfo)) plotInfoTable <- rbind(plotInfoTable,plotinfo)
         }
       }
     } # end loop over timeseries subplots
+
+    plotinfo <- SSplotSummaryF(replist=replist,
+                               uncertainty=uncertainty,
+                               plot=!png, print=png,
+                               verbose=verbose,
+                               pwidth=pwidth, pheight=pheight, punits=punits,
+                               ptsize=ptsize, res=res, 
+                               plotdir=plotdir)
+    if(!is.null(plotinfo)) plotInfoTable <- rbind(plotInfoTable,plotinfo)
+
   } # end if igroup in plot or print
 
   ##########################################
@@ -356,7 +556,10 @@ SS_plots <-
                   pwidth=pwidth, pheight=pheight, punits=punits,
                   ptsize=ptsize, res=res,cex.main=cex.main,
                   catchasnumbers=catchasnumbers,
+		  order="default",
                   catchbars=catchbars,
+                  labels=catlabels,
+                  legendloc=legendloc,
                   plotdir=plotdir)
     plotinfo <- temp$plotinfo
     if(!is.null(plotinfo)) plotInfoTable <- rbind(plotInfoTable,plotinfo)
@@ -459,6 +662,7 @@ SS_plots <-
                     areanames=areanames,
                     areacols=areacols,
                     pntscalar=pntscalar.nums,
+                    bublegend=showlegend,
                     plot=!png, print=png,
                     pwidth=pwidth, pheight=pheight, punits=punits,
                     ptsize=ptsize, res=res,cex.main=cex.main,
@@ -485,27 +689,29 @@ SS_plots <-
       if(lenCompDatGroup %in% plot)  # data only aspects
       {
         if(verbose) cat("Starting length comp data plots (group ",lenCompDatGroup,")\n",sep="")
-        # length comp bar plot
+        # length comp polygon and bubble plots
         plotinfo <-
           SSplotComps(replist=replist,datonly=TRUE,kind="LEN",bub=TRUE,verbose=verbose,fleets=fleets,
                       fleetnames=fleetnames,
                       samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=FALSE,
-                      minnbubble=minnbubble, pntscalar=pntscalar,
+                      minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.dat,
+                      bublegend=showlegend,
                       maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
                       plot=!png, print=png,
                       plotdir=plotdir,cex.main=cex.main,
-                      scalebins=scalebins,
+                      scalebins=scalebins, scalebubbles=scalebubbles,
                       pwidth=pwidth, pheight=pheight, punits=punits,
                       ptsize=ptsize, res=res,
                       ...)
         if(!is.null(plotinfo)) plotInfoTable <- rbind(plotInfoTable,plotinfo)
-        # size comp bubble plot
+        # size comp polygon and bubble plots
         for(sizemethod in sort(unique(replist$sizedbase$method))){
           plotinfo <-
             SSplotComps(replist=replist,datonly=TRUE,kind="SIZE",sizemethod=sizemethod,
                         bub=TRUE,verbose=verbose,fleets=fleets,fleetnames=fleetnames,
                         samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=FALSE,
-                        minnbubble=minnbubble, pntscalar=pntscalar,
+                        minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.dat,
+                        bublegend=showlegend,
                         maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
                         plot=!png, print=png,
                         plotdir=plotdir,cex.main=cex.main,
@@ -518,26 +724,13 @@ SS_plots <-
       }
       if(ageCompDatGroup %in% plot){
         if(verbose) cat("Starting age comp data plots (group ",ageCompDatGroup,")\n",sep="")
-        # age comp bar plot
-        plotinfo <-
-          SSplotComps(replist=replist,datonly=TRUE,kind="AGE",bub=FALSE,verbose=verbose,fleets=fleets,
-                      fleetnames=fleetnames,
-                      samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=FALSE,
-                      minnbubble=minnbubble, pntscalar=pntscalar,
-                      maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
-                      plot=!png, print=png,
-                      plotdir=plotdir,cex.main=cex.main,
-                      scalebins=scalebins,
-                      pwidth=pwidth, pheight=pheight, punits=punits,
-                      ptsize=ptsize, res=res,
-                      ...)
-        if(!is.null(plotinfo)) plotInfoTable <- rbind(plotInfoTable,plotinfo)
-        # age comp bubble plot
+        # age comp polygon and bubble plots
         plotinfo <-
           SSplotComps(replist=replist,datonly=TRUE,kind="AGE",bub=TRUE,verbose=verbose,fleets=fleets,
                       fleetnames=fleetnames,
                       samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=FALSE,
-                      minnbubble=minnbubble, pntscalar=pntscalar,
+                      minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.dat,
+                      bublegend=showlegend,
                       maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
                       plot=!png, print=png,
                       plotdir=plotdir,cex.main=cex.main,
@@ -546,26 +739,13 @@ SS_plots <-
                       ptsize=ptsize, res=res,
                       ...)
         if(!is.null(plotinfo)) plotInfoTable <- rbind(plotInfoTable,plotinfo)
-        # ghost age comp bar plot
-        plotinfo <-
-          SSplotComps(replist=replist,datonly=TRUE,kind="GSTAGE",bub=FALSE,verbose=verbose,fleets=fleets,
-                      fleetnames=fleetnames,
-                      samplesizeplots=samplesizeplots,showsampsize=FALSE,showeffN=FALSE,
-                      minnbubble=minnbubble, pntscalar=pntscalar,
-                      maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
-                      plot=!png, print=png,
-                      plotdir=plotdir,cex.main=cex.main,
-                      scalebins=scalebins,
-                      pwidth=pwidth, pheight=pheight, punits=punits,
-                      ptsize=ptsize, res=res,
-                      ...)
-        if(!is.null(plotinfo)) plotInfoTable <- rbind(plotInfoTable,plotinfo)
-        # ghost age comp bubble plot
+        # ghost age comp polygon and bubble plots
         plotinfo <-
           SSplotComps(replist=replist,datonly=TRUE,kind="GSTAGE",bub=TRUE,verbose=verbose,fleets=fleets,
                       fleetnames=fleetnames,
                       samplesizeplots=samplesizeplots,showsampsize=FALSE,showeffN=FALSE,
-                      minnbubble=minnbubble, pntscalar=pntscalar,
+                      minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.dat,
+                      bublegend=showlegend,
                       maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
                       plot=!png, print=png,
                       plotdir=plotdir,cex.main=cex.main,
@@ -583,9 +763,12 @@ SS_plots <-
           SSplotComps(replist=replist,datonly=TRUE,kind="cond",bub=TRUE,verbose=verbose,fleets=fleets,
                       fleetnames=fleetnames,
                       samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=FALSE,
-                      minnbubble=minnbubble, pntscalar=pntscalar,
+                      sampsizeline=sampsizeline,effNline=effNline,
+                      minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.dat,
+                      bublegend=showlegend,
                       maxrows=maxrows,maxcols=maxcols,maxrows2=maxrows2,maxcols2=maxcols2,
                       fixdims=fixdims,rows=rows,cols=cols,
+                      andrerows=andrerows,
                       plot=!png, print=png,
                       plotdir=plotdir,cex.main=cex.main,
                       scalebins=scalebins, scalebubbles=scalebubbles,
@@ -609,7 +792,8 @@ SS_plots <-
         SSplotComps(replist=replist,datonly=FALSE,kind="LEN",bub=TRUE,verbose=verbose,fleets=fleets,
                     fleetnames=fleetnames,
                     samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=showeffN,
-                    minnbubble=minnbubble, pntscalar=pntscalar,
+                    minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.pearson,
+                    bublegend=showlegend,
                     maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
                     plot=!png, print=png,smooth=smooth,plotdir=plotdir,
                     maxneff=maxneff,cex.main=cex.main,cohortlines=cohortlines,
@@ -623,7 +807,8 @@ SS_plots <-
         SSplotComps(replist=replist,datonly=FALSE,kind="GSTLEN",bub=TRUE,verbose=verbose,fleets=fleets,
                     fleetnames=fleetnames,
                     samplesizeplots=FALSE,showsampsize=FALSE,showeffN=FALSE,
-                    minnbubble=minnbubble, pntscalar=pntscalar,
+                    minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.pearson,
+                    bublegend=showlegend,
                     maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
                     plot=!png, print=png,smooth=smooth,plotdir=plotdir,
                     maxneff=maxneff,cex.main=cex.main,cohortlines=cohortlines,
@@ -639,7 +824,8 @@ SS_plots <-
           SSplotComps(replist=replist,datonly=FALSE,kind="SIZE",sizemethod=sizemethod,
                       bub=TRUE,verbose=verbose,fleets=fleets, fleetnames=fleetnames,
                       samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=showeffN,
-                      minnbubble=minnbubble, pntscalar=pntscalar,
+                      minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.pearson,
+                      bublegend=showlegend,
                       maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
                       plot=!png, print=png,smooth=smooth,plotdir=plotdir,
                       maxneff=maxneff,cex.main=cex.main,cohortlines=cohortlines,
@@ -663,7 +849,8 @@ SS_plots <-
         SSplotComps(replist=replist,datonly=FALSE,kind="AGE",bub=TRUE,verbose=verbose,fleets=fleets,
                     fleetnames=fleetnames,
                     samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=showeffN,
-                    minnbubble=minnbubble, pntscalar=pntscalar,
+                    minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.pearson,
+                    bublegend=showlegend,
                     maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
                     plot=!png, print=png,smooth=smooth,plotdir=plotdir,
                     maxneff=maxneff,cex.main=cex.main,
@@ -676,7 +863,8 @@ SS_plots <-
         SSplotComps(replist=replist,datonly=FALSE,kind="GSTAGE",bub=TRUE,verbose=verbose,fleets=fleets,
                     fleetnames=fleetnames,
                     samplesizeplots=FALSE,showsampsize=FALSE,showeffN=FALSE,
-                    minnbubble=minnbubble, pntscalar=pntscalar,
+                    minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.pearson,
+                    bublegend=showlegend,
                     maxrows=maxrows,maxcols=maxcols,fixdims=fixdims,rows=rows,cols=cols,
                     plot=!png, print=png,smooth=smooth,plotdir=plotdir,
                     maxneff=maxneff,cex.main=cex.main,
@@ -700,7 +888,9 @@ SS_plots <-
           SSplotComps(replist=replist,subplots=3,datonly=FALSE,kind="cond",bub=TRUE,verbose=verbose,fleets=fleets,
                       fleetnames=fleetnames,
                       samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=showeffN,
-                      minnbubble=minnbubble, pntscalar=pntscalar,
+                      sampsizeline=sampsizeline,effNline=effNline,
+                      minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.pearson,
+                      bublegend=showlegend,
                       maxrows=maxrows,maxcols=maxcols,maxrows2=maxrows2,maxcols2=maxcols2,fixdims=fixdims,rows=rows,cols=cols,
                       plot=!png, print=png,smooth=smooth,plotdir=plotdir,
                       maxneff=maxneff,cex.main=cex.main,
@@ -717,7 +907,9 @@ SS_plots <-
                       fleetnames=fleetnames,
                       aalbin=aalbin,aalyear=aalyear,
                       samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=showeffN,
-                      minnbubble=minnbubble, pntscalar=pntscalar,
+                      sampsizeline=sampsizeline,effNline=effNline,
+                      minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.pearson,
+                      bublegend=showlegend,
                       maxrows=maxrows,maxcols=maxcols,maxrows2=maxrows2,maxcols2=maxcols2,fixdims=fixdims,rows=rows,cols=cols,
                       plot=!png, print=png,smooth=smooth,plotdir=plotdir,
                       maxneff=maxneff,cex.main=cex.main,
@@ -734,7 +926,8 @@ SS_plots <-
                       fleetnames=fleetnames,
                       aalbin=aalbin,
                       samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=showeffN,
-                      minnbubble=minnbubble, pntscalar=pntscalar,
+                      minnbubble=minnbubble, pntscalar=pntscalar, cexZ1=bub.scale.pearson,
+                      bublegend=showlegend,
                       maxrows=maxrows,maxcols=maxcols,maxrows2=maxrows2,maxcols2=maxcols2,fixdims=fixdims,rows=rows,cols=cols,
                       plot=!png, print=png,smooth=smooth,plotdir=plotdir,
                       maxneff=maxneff,cex.main=cex.main,
@@ -769,6 +962,7 @@ SS_plots <-
                       samplesizeplots=samplesizeplots,showsampsize=showsampsize,showeffN=showeffN,
                       minnbubble=minnbubble, pntscalar=pntscalar,
                       maxrows=maxrows,maxcols=maxcols,maxrows2=maxrows2,maxcols2=maxcols2,fixdims=fixdims,rows=rows,cols=cols,
+                      andrerows=andrerows,
                       plot=!png, print=png,smooth=smooth,plotdir=plotdir,
                       maxneff=maxneff,cex.main=cex.main,
                       scalebins=FALSE,
