@@ -1,6 +1,36 @@
+#' Get output from multiple Stock Synthesis models.
+#' 
+#' Apply the function \code{\link{SS_output}} multiple times and save output as
+#' individual objects or a list of lists.
+#' 
+#' 
+#' @param keyvec A vector of strings that are appended to the output files from
+#' each model if models are all in one directory. Default=NULL.
+#' @param dirvec A vector of directories (full path or relative to working
+#' directory) in which model output is located. Default=NULL.
+#' @param getcovar Choice to read or not read covar.sso output (saves time and
+#' memory). Default=TRUE.
+#' @param getcomp Choice to read or not read CompReport.sso output (saves time
+#' and memory). Default=TRUE.
+#' @param forecast Choice to read or not read forecast quantities.
+#' Default=FALSE.
+#' @param verbose Print various messages to the command line as the function
+#' runs? Default=TRUE.
+#' @param ncols Maximum number of columns in Report.sso (same input as for
+#' \code{\link{SS_output}}).  Default=210.
+#' @param listlists Save output from each model as a element of a list (i.e.
+#' make a list of lists). Default = TRUE.
+#' @param underscore Add an underscore '_' between any file names and any keys
+#' in keyvec. Default=FALSE.
+#' @param save.lists Save each list of parsed output as a .Rdata file (with default
+#' filenaming convention based on iteration and date stamp.
+#' @author Ian Taylor
+#' @seealso \code{\link{SS_output}} \code{\link{SSsummarize}}
+#' @keywords data manip list
 SSgetoutput <-
 function(keyvec=NULL,dirvec=NULL,getcovar=TRUE,getcomp=TRUE,forecast=FALSE,
-         verbose=TRUE,ncols=210,listlists=TRUE,underscore=FALSE)
+         verbose=TRUE,ncols=210,listlists=TRUE,underscore=FALSE,
+         save.lists=FALSE)
 {
   # a function to run the function SS_output to create a list in the R workspace
   # for a Stock Synthesis model with output filenames ending with the same "key"
@@ -81,6 +111,11 @@ function(keyvec=NULL,dirvec=NULL,getcovar=TRUE,getcomp=TRUE,forecast=FALSE,
     ##     cat("created new object:",newobject,"\n")
     ##   }
     ## }
+
+    if(save.lists){
+      biglist.file <- paste("biglist",i,"_",format(Sys.time(),'%d-%b-%Y_%H.%M' ),".Rdata",sep="")
+      save(biglist, file=biglist.file)
+    }
   }
   return(invisible(biglist))
 }
