@@ -1,3 +1,40 @@
+#' Plot movement rates from model output
+#' 
+#' Plots estimated movement rates in final year for each area/seaon with movement as
+#' reported in Report.sso. If movement is time-varying, an additional figure shows
+#' pattern across years.
+#' 
+#' 
+#' @param replist list created by \code{\link{SS_output}}
+#' @param plot plot to active plot device?
+#' @param print print to PNG files?
+#' @param subplots which subplots to create
+#' @param plotdir where to put the plots (uses model directory by default)
+#' @param colvec vector of colors for each movement rate in the plot
+#' @param ylim optional input for y range of the plot. By default plot ranges
+#' from 0 to 10\% above highest movement rate (not including fish staying in an
+#' area).
+#' @param legend add a legend designating which color goes with which pair of
+#' areas?
+#' @param legendloc location passed to legend function (if used)
+#' @param moveseas choice of season for which movemement rates are shown
+#' @param pwidth width of plot written to PNG file
+#' @param pheight height of plot written to PNG file
+#' @param punits units for PNG file
+#' @param res resolution for PNG file
+#' @param ptsize ptsize for PNG file
+#' @param cex.main Character expansion parameter for plot titles
+#' @param verbose Print information on function progress.
+#' @author Ian Taylor
+#' @seealso \code{\link{SS_output}}, \code{\link{SSplotMovementRates}},
+#' \code{\link{IOTCmove}}
+#' @keywords hplot
+#' @examples
+#' 
+#'   \dontrun{
+#'     SSplotMovementRates(myreplist)
+#'   }
+#' 
 SSplotMovementRates <-
   function(replist, plot=TRUE, print=FALSE, subplots=1:2,
            plotdir="default",
@@ -54,26 +91,26 @@ SSplotMovementRates <-
         if(ylim[1]=="default") ylim=c(0,1.1*max(move))
         main <- paste("Movement rates\n(fraction moving per year in season ",moveseas[iseas],")",sep="")
         # bundle plot as function below
-        tempfun <- function(){
+        move.endyr.fn <- function(){
           matplot(0:accuage,t(move3),
-                  type='l',lwd=3,lty=1,col=colvec,
+                  type='l',lwd=3,col=colvec,
                   ylab="Movement rate",xlab="Age (years)",
                   main=main,
                   cex.main=cex.main)
           abline(h=0,col='grey')
           if(legend){
             legend(legendloc,lwd=3,bty="n",
-                   col=colvec,
+                   col=colvec,lty=1:nrow(move2),
                    legend=paste("area",move2$Source_area,"to area",move2$Dest_area)
                    )
           }
         }
-        if(plot) tempfun()
+        if(plot) move.endyr.fn()
         if(print){
           file <- paste(plotdir,"/move1_movement_rates.png",sep="")
           caption <- main
           plotinfo <- pngfun(file=file, caption=caption)
-          tempfun()
+          move.endyr.fn()
           dev.off()
         }
       }
@@ -181,17 +218,17 @@ SSplotMovementRates <-
         movetable <- moveByYr[dimnames(moveByYr)$area==Dest_area, ,imove,]
         movetable <- moveByYr[1, ,imove,]
         main <- paste("Time-varying movement from area",Source_area,"to area",Dest_area)
-        tempfun <- function(){
+        move.mountains.fn <- function(){
           mountains(zmat=t(movetable),xvec=0:accuage,yvec=yrvec,xlab='Age',ylab='Year')
           title(main=main,cex.main=cex.main)
         }
         
-        if(plot) tempfun()
+        if(plot) move.mountains.fn()
         if(print){
           file <- paste(plotdir,"/move2_time-varying_movement_rates.png",sep="")
           caption <- main
           plotinfo <- pngfun(file=file, caption=caption)
-          tempfun()
+          move.mountains.fn()
           dev.off()
         }
       }
