@@ -1,12 +1,72 @@
+#' Plot selectivity
+#' 
+#' Plot selectivity, including retention and other quantities, with additional
+#' plots for time-varying selectivity.
+#' 
+#' 
+#' @param replist List created by \code{SS_output}
+#' @param fleets Optional vector to subset fleets for which to make plots
+#' @param infotable Optional table of information controlling appearance of
+#' plot and legend. Is produced as output and can be modified and entered as
+#' input.
+#' @param fleetnames Optional replacement for fleenames used in data file
+#' @param sizefactors Which elements of the factors column of SIZE_SELEX should
+#' be included in plot of selectivity across multiple fleets?
+#' @param agefactors Which elements of the factors column of AGE_SELEX should
+#' be included in plot of selectivity across multiple fleets?
+#' @param years Which years for selectivity are shown in multi-line plot
+#' (default = last year of model).
+#' @param season Which season (if seasonal model) for selectivity shown in
+#' multi-line plot (default = 1).
+#' @param sexes Optional vector to subset genders for which to make plots
+#' (1=females, 2=males)
+#' @param selexlines Vector to select which lines get plotted. values are 1.
+#' Selectivity, 2. Retention, 3. Discard mortality, 4. Keep = Sel*Ret, 5. Dead
+#' = Sel*(Ret+(1-Ret)*Mort).
+#' @param subplot Vector controlling which subplots to create
+#' @param skipAgeSelex10 Exclude plots for age selectivity type 10 (selectivity
+#' = 1.0 for all ages beginning at age 1)?
+#' @param lwd Line widths for plots
+#' @param fleetcols Optional vector of colors for each fleet (in multi-fleet
+#' plots)
+#' @param fleetpch Optional vector of plot characters for each fleet (in
+#' multi-fleet plots)
+#' @param fleetlty Optional vector of line types for each fleet (in multi-fleet
+#' plots)
+#' @param spacepoints number of years between points shown on top of lines (for
+#' long timeseries, points every year get mashed together)
+#' @param staggerpoints number of years to stagger the first point (if
+#' \code{spacepoints > 1}) for each line (so that adjacent lines have points in
+#' different years)
+#' @param legendloc location of legend. See ?legend for more info.
+#' @param plot Plot to active plot device?
+#' @param print Print to PNG files?
+#' @param add Add to existing plot (not yet implemented)
+#' @param labels vector of labels for plots (titles and axis labels)
+#' @param col1 color for female growth curve
+#' @param col2 color for male growth curve
+#' @param pwidth width of plot written to PNG file
+#' @param pheight height of plot written to PNG file
+#' @param punits units for PNG file
+#' @param res resolution for PNG file
+#' @param ptsize ptsize for PNG file
+#' @param cex.main character expansion for plot titles
+#' @param showmain Include main title at top of plot?
+#' @param plotdir Directory where PNG files will be written. By default it will
+#' be the directory where the model was run.
+#' @param verbose report progress to R GUI?
+#' @author Ian Stewart, Ian Taylor
+#' @seealso \code{\link{SS_plots}}, \code{\link{SS_output}}
+#' @keywords hplot
 SSplotSelex <-
   function(replist, infotable=NULL,
            fleets="all", fleetnames="default",
            sizefactors=c("Lsel"),
-           agefactors=c("Asel"),
+           agefactors=c("Asel","Asel2"),
            years="endyr",
            season=1,
            sexes="all", 
-           selexlines=1:5,
+           selexlines=1:6,
            subplot=1:25,
            skipAgeSelex10=TRUE,
            plot=TRUE, print=FALSE, add=FALSE,
@@ -25,7 +85,7 @@ SSplotSelex <-
            legendloc="bottomright",
            pwidth = 7, pheight = 7, punits = "in",
            res = 300, ptsize = 12,
-           cex.main=1, plotdir = "default",
+           cex.main=1, showmain=TRUE, plotdir = "default",
            verbose = TRUE)
 {
   # subplots:
@@ -33,6 +93,9 @@ SSplotSelex <-
   #### all fleets grouped (length, and then age)
   # 1.  selectivity at length in end year for all fleets shown together
   # 2.  selectivity at age in end year for all fleets shown together
+  #     (this includes both age-based selectivity "Asel" and age values derived
+  #      from length-based, "Asel2". You can choose only one using
+  #      "agefactors" if needed.)
 
   ## time-varying stuff
   # 3.  selectivity at length time-varying surface
@@ -58,6 +121,8 @@ SSplotSelex <-
   # 21. selecitivity at age and length contour with overlaid growth curve
   # 22. selectivity with uncertainty if requested at end of control file
 
+  # empty table into which information on line types etc. might be copied
+  infotable2 <- NULL
   
   nsexes         <- replist$nsexes
   nseasons       <- replist$nseasons
@@ -71,6 +136,7 @@ SSplotSelex <-
   endyr          <- replist$endyr
   FleetNames     <- replist$FleetNames
   growdat        <- replist$endgrowth
+  growthCVtype   <- replist$growthCVtype
   mainmorphs     <- replist$mainmorphs
   nareas         <- replist$nareas
   ngpatterns     <- replist$ngpatterns
@@ -125,7 +191,10 @@ SSplotSelex <-
                            ageselex$fleet %in% fleets &
                            ageselex$gender %in% sexes,]
     }
-    if(!factor %in% unique(c(sizeselex$Factor,ageselex$factor))) stop("bad factor")
+    if(!factor %in% unique(c(sizeselex$Factor,ageselex$factor))){
+      cat("In selectivity plots, factor ",factor,"not found in age- or length-based selectivity.\n")
+      return()
+    }
     if(nrow(allselex)==0){
       cat("combination of season, fleets, & sexes didn't produce any results\n")
       return()
@@ -185,6 +254,7 @@ SSplotSelex <-
     allselex <- allselex2 <- allselex[allselex$year %in% years,]
 
     # do some processing
+    gender <- allselex$gender
     if(!agebased){
       allselex <- allselex[,-(1:5)]
       xlab <- labels[1]
@@ -193,61 +263,73 @@ SSplotSelex <-
       allselex <- allselex[,-(1:7)]
       xlab <- labels[2]
     }
-
-    if(is.null(infotable)){
+    if(!is.null(infotable)){
+      infotable2 <- infotable
+      good <- gender %in% infotable$gender
+      allselex <- allselex[good,]
+      allselex2 <- allselex2[good,]
+      if(nrow(infotable2)!=nrow(allselex)){
+        stop("Problem with input 'infotable'. Number of rows doesn't match.")
+      }
+    }else{
       # make table of info for each row (unless it is supplied already)
-      infotable <- allselex2[c("fleet","gender","year")]
-      infotable$ifleet <- NA
-      infotable$FleetName <- fleetnames[infotable$fleet]
-      infotable$longname <- infotable$FleetName
-      for(i in 1:nrow(infotable)) infotable$year_range[i] <- year_ranges[years==infotable$year[i]]
+      infotable2 <- allselex2[c("fleet","gender","year")]
+      infotable2$ifleet <- NA
+      infotable2$FleetName <- fleetnames[infotable2$fleet]
+      infotable2$longname <- infotable2$FleetName
+      for(i in 1:nrow(infotable2)) infotable2$year_range[i] <- year_ranges[years==infotable2$year[i]]
 
-      if(length(unique(infotable$year)) > 1){
-        infotable$longname <- paste(infotable$FleetName,infotable$year_range)
+      if(length(unique(infotable2$year)) > 1){
+        infotable2$longname <- paste(infotable2$FleetName,infotable2$year_range)
       }
-      
       # check for whether there are differences between males and females
-      twosex <- all(1:2 %in% infotable$gender) && any(allselex[infotable$gender==1,]!=allselex[infotable$gender==2,])
+      twosex <- all(1:2 %in% infotable2$gender) && any(allselex[infotable2$gender==1,]!=allselex[infotable2$gender==2,])
       if(!twosex){ # show only sex with lowest number if no differences between genders
-        good <- infotable$gender==min(infotable$gender)
+        good <- infotable2$gender==min(infotable2$gender)
         allselex <- allselex[good,]
         allselex2 <- allselex2[good,]
-        infotable <- infotable[good,]
+        infotable2 <- infotable2[good,]
       }else{
-        infotable$longname <- paste(infotable$longname, c("(f)","(m)")[infotable$gender])
+        infotable2$longname <- paste(infotable2$longname, c("(f)","(m)")[infotable2$gender])
       }
       
       # add index from 1 up to number of fleets plotted
-      allfleets <- sort(unique(infotable$fleet))
+      allfleets <- sort(unique(infotable2$fleet))
       for(ifleet in 1:length(allfleets))
-        infotable$ifleet[infotable$fleet==allfleets[ifleet]] <- ifleet
+        infotable2$ifleet[infotable2$fleet==allfleets[ifleet]] <- ifleet
       # choose colors
       colvec <- rich.colors.short(length(allfleets))
-      infotable$col <- colvec[infotable$ifleet]
+      infotable2$col <- colvec[infotable2$ifleet]
       # choose line types
-      infotable$lty <- 1
+      infotable2$lty <- 1
       # either line by gender
-      infotable$lwd <- lwd
-      if(twosex) infotable$lty <- infotable$gender
+      infotable2$lwd <- lwd
+      if(twosex) infotable2$lty <- infotable2$gender
       # or line by year (with line width by gender)
-      allyears <- sort(unique(infotable$year))
+      allyears <- sort(unique(infotable2$year))
       if(length(allyears)>1){
         for(iyear in 1:length(allyears))
-          infotable$lty[infotable$year==allyears[iyear]] <- iyear
-        if(twosex) infotable$lwd[infotable$gender==2] <- lwd/2
+          infotable2$lty[infotable2$year==allyears[iyear]] <- iyear
+        if(twosex) infotable2$lwd[infotable2$gender==2] <- lwd/2
       }
       # choose plot characters
-      infotable$pch <- infotable$ifleet %% 25
+      infotable2$pch <- infotable2$ifleet %% 25
     }
-    
-    if(factor=="Lsel") main <- paste("Length-based selectivity by fleet")
-    if(factor=="Asel") main <- paste("Age-based selectivity by fleet")
-    if(factor=="Asel2") main <- paste("Derived age-based from length-based selectivity by fleet")
-    if(length(unique(infotable$year))==1){
-      main <- paste(main,"in",years)
+
+    main <- factor
+    if(factor=="Lsel") main <- paste("Length-based selectivity")
+    if(factor=="Asel") main <- paste("Age-based selectivity")
+    if(factor=="Asel2") main <- paste("Derived age-based from length-based selectivity")
+    if(factor=="Ret") main <- paste("Retention")
+    if(length(fleets)>1) main <- paste(main, "by fleet")
+    if(length(fleets)==1) main <- paste(main, "for", fleetnames[fleets])
+       
+    if(length(unique(infotable2$year))==1){
+      main <- paste(main,"in",unique(infotable2$year))
     }
+    if(!showmain) main <- NULL
 ## cat("info on plot for debugging:\n")    
-## print(infotable)
+## print(infotable2)
     
     bins <- as.numeric(names(allselex))
 
@@ -258,46 +340,50 @@ SSplotSelex <-
     abline(h=0,col="grey")
     abline(h=1,col="grey")
     # add lines for selectivities
-    matplot(x=bins, y=t(allselex), col=infotable$col, 
-            lty=infotable$lty, lwd=infotable$lwd, type="l",add=TRUE)
+    matplot(x=bins, y=t(allselex), col=infotable2$col, 
+            lty=infotable2$lty, lwd=infotable2$lwd, type="l",add=TRUE)
     # add points on top of lines (first subsetting to optionally show fewer points)
     allselex2 <- allselex
     if(spacepoints > 0){
       for(iline in 1:nrow(allselex))
         allselex2[iline,(1:ncol(allselex))%%spacepoints != (staggerpoints*iline)%%spacepoints] <- NA
-      matplot(x=bins, y=t(allselex2), col=infotable$col,
-              lwd=infotable$lwd, pch=infotable$pch, type="p",add=TRUE)
+      matplot(x=bins, y=t(allselex2), col=infotable2$col,
+              lwd=infotable2$lwd, pch=infotable2$pch, type="p",add=TRUE)
     }else{
       # if 'spacepoints' is less than or equal to 0, don't show points
-      infotable$pch <- NA
+      infotable2$pch <- NA
     }
     # add legend
-    if(nrow(infotable)>1)
-      legend(legendloc, inset=c(0,0.05), legend=infotable$longname, col=infotable$col,
-             lty=infotable$lty, pch=infotable$pch, lwd=infotable$lwd, bty='n')
-    return(infotable)
+    if(nrow(infotable2)>1)
+      legend(legendloc, inset=c(0,0.05), legend=infotable2$longname, col=infotable2$col,
+             seg.len=4,
+             lty=infotable2$lty, pch=infotable2$pch, lwd=infotable2$lwd, bty='n')
+    return(infotable2)
   }
 
   if(1 %in% subplot){
     for(ifactor in 1:length(sizefactors)){
-      if(plot) infotable <- plotAllSel(factor=sizefactors[ifactor])
+      if(plot) infotable2 <- plotAllSel(factor=sizefactors[ifactor])
       if(print){
         file <- paste(plotdir,"sel01_multiple_fleets_length",ifactor,".png",sep="")
         caption <- "Selectivity at length for multiple fleets."
         plotinfo <- pngfun(file=file, caption=caption)
-        infotable <- plotAllSel(factor="Lsel")
+        infotable2 <- plotAllSel(factor="Lsel")
         dev.off()
       }
     }
   }
   if(2 %in% subplot){
     for(ifactor in 1:length(agefactors)){
-      if(plot) infotable <- plotAllSel(factor=agefactors[ifactor])
+      factor <- agefactors[ifactor]
+      if(plot) infotable2 <- plotAllSel(factor=factor)
       if(print){
         file <- paste(plotdir,"sel02_multiple_fleets_age",ifactor,".png",sep="")
         caption <- "Selectivity at age for multiple fleets."
+        if(factor=="Asel2")
+          caption <- paste("Selectivity at age derived from selectivity at length for multiple fleets.")
         plotinfo <- pngfun(file=file, caption=caption)
-        infotable <- plotAllSel(factor="Asel")
+        infotable2 <- plotAllSel(factor=factor)
         dev.off()
       }
     }
@@ -471,6 +557,10 @@ SSplotSelex <-
           plotkeep <- usekeep[usekeep$year==useyr,]
           plotmort <- usemort[usemort$year==useyr,]
           plotdead <- usedead[usedead$year==useyr,]
+          # compute discard as function of size: selectivity*(1 - retention)
+          plotdisc <- plotret
+          plotdisc[-(1:5)] <- vals*(1-plotret[,-(1:5)])
+          # add additional lines if requested
           if(2%in%selexlines){
             lines((as.numeric(as.vector(names(plotret)[-(1:5)]))),(as.numeric(as.character(plotret[1,-(1:5)]))),col="red",type="o",pch=3,cex=.9)
             ylab <- paste(ylab,", Retention",sep="")
@@ -481,10 +571,13 @@ SSplotSelex <-
           }
           if(4%in%selexlines) lines((as.numeric(as.vector(names(plotkeep)[-(1:5)]))),(as.numeric(as.character(plotkeep[1,-(1:5)]))),col="purple",type="o",pch=2,cex=.9)
           if(5%in%selexlines) lines((as.numeric(as.vector(names(plotdead)[-(1:5)]))),(as.numeric(as.character(plotdead[1,-(1:5)]))),col="green3",type="o",pch=5,cex=.9)
+          if(6%in%selexlines) lines((as.numeric(as.vector(names(plotdead)[-(1:5)]))),(as.numeric(as.character(plotdisc[1,-(1:5)]))),col="grey50",type="o",pch=6,cex=.9)
+          # add legend
           legend(legendloc,inset=c(0,0.05),bty="n",
-      	   c(labels[4],labels[5],labels[6],"Keep = Sel*Ret","Dead = Sel*(Ret+(1-Ret)*Mort)")[selexlines],
-      	   lty=1,col=c("blue","red","orange","purple","green3")[selexlines],
-      	   pch=c(1,3,4,2,5)[selexlines], pt.cex=c(1.1,.9,.9,.9,.9)[selexlines])
+      	   c(labels[4], labels[5], labels[6], "Keep = Sel*Ret",
+             "Dead = Sel*(Ret+(1-Ret)*Mort)","Discard = Sel*(1-Ret)")[selexlines],
+      	   lty=1,col=c("blue","red","orange","purple","green3","grey50")[selexlines],
+      	   pch=c(1,3,4,2,5,6)[selexlines], pt.cex=c(1.1,.9,.9,.9,.9,.9)[selexlines])
         }
         mtext(ylab,side=2,line=3)
       }
@@ -510,109 +603,103 @@ SSplotSelex <-
   
   # Age based selex
   ylab <- labels[4]
-  for(i in fleets)
-  {
-    for(m in sexes)
-    {
-      if(m==1 & nsexes==1) sextitle1 <- "Time-"
-      if(m==1 & nsexes==2) sextitle1 <- "Female time-"
-      if(m==2) sextitle1 <- "Male time-"
-      if(m==1 & nsexes==1) sextitle2 <- "Ending"
-      if(m==1 & nsexes==2) sextitle2 <- "Female ending"
-      if(m==2) sextitle2 <- "Male ending"
-      ageselexcols <- (1:ncol(ageselex))[names(ageselex) %in% as.character(0:accuage)]
-      plotageselex <- ageselex[ageselex$factor=="Asel" & ageselex$fleet==i & ageselex$year!=startyr-3 & ageselex$gender==m,]
-      # test for time-varying age selectivity
-      time <- any(apply(plotageselex[-c(1,nrow(plotageselex)),ageselexcols],2,function(x){any(x!=x[1])}))      
-      if(time)
-      {
-        if((min(as.numeric(as.vector(t(plotageselex[,-(1:7)])))) < 1))
-        {
-          x <- seq(0,accuage,by=1)
-          y <- as.numeric(plotageselex$year)
-          z <- plotageselex[,-(1:7)]
-          z <- matrix(as.numeric(as.matrix(z)),ncol=ncol(z))
-          z <- t(z)
-          main <- paste(sextitle1,"varying selectivity for ", fleetnames[i],sep="")
-          if(plot){
-            if(11 %in% subplot) persp(x,y,z,col="white",xlab=labels[2],ylab=labels[3],zlab=ylab,expand=0.5,box=TRUE,main=main,cex.main=cex.main,ticktype="detailed",phi=35,theta=-10)
-            if(12 %in% subplot) contour(x,y,z,nlevels=5,xlab=labels[2],main=main,cex.main=cex.main,col=ians_blues,lwd=lwd)}
-          if(print){
-            if(11 %in% subplot){
-              file <- paste(plotdir,"sel11_timevary_surf_flt",i,"sex",m,".png",sep="")
-              caption <- main
-              plotinfo <- pngfun(file=file, caption=caption)
-              persp(x,y,z,col="white",xlab=labels[2],ylab=labels[3],zlab=ylab,expand=0.5,box=TRUE,main=main,cex.main=cex.main,ticktype="detailed",phi=35,theta=-10)
-              dev.off()
+  for(facnum in 1){
+    factor <- c("Asel","Asel2")[facnum]
+    for(i in fleets){
+      for(m in sexes){
+        if(m==1 & nsexes==1) sextitle1 <- "Time-"
+        if(m==1 & nsexes==2) sextitle1 <- "Female time-"
+        if(m==2) sextitle1 <- "Male time-"
+        if(m==1 & nsexes==1) sextitle2 <- "Ending"
+        if(m==1 & nsexes==2) sextitle2 <- "Female ending"
+        if(m==2) sextitle2 <- "Male ending"
+        ageselexcols <- (1:ncol(ageselex))[names(ageselex) %in% as.character(0:accuage)]
+        plotageselex <- ageselex[ageselex$factor==factor & ageselex$fleet==i & ageselex$year!=startyr-3 & ageselex$gender==m,]
+        # test for time-varying age selectivity
+        time <- any(apply(plotageselex[-c(1,nrow(plotageselex)),ageselexcols],2,function(x){any(x!=x[1])}))      
+        if(time){
+          if((min(as.numeric(as.vector(t(plotageselex[,-(1:7)])))) < 1)){
+            x <- seq(0,accuage,by=1)
+            y <- as.numeric(plotageselex$year)
+            z <- plotageselex[,-(1:7)]
+            z <- matrix(as.numeric(as.matrix(z)),ncol=ncol(z))
+            z <- t(z)
+            main <- paste(sextitle1,"varying selectivity for ", fleetnames[i],sep="")
+            if(plot){
+              if(11 %in% subplot) persp(x,y,z,col="white",xlab=labels[2],ylab=labels[3],zlab=ylab,expand=0.5,box=TRUE,main=main,cex.main=cex.main,ticktype="detailed",phi=35,theta=-10)
+              if(12 %in% subplot) contour(x,y,z,nlevels=5,xlab=labels[2],main=main,cex.main=cex.main,col=ians_blues,lwd=lwd)}
+            if(print){
+              if(11 %in% subplot){
+                file <- paste(plotdir,"sel11_timevary_surf_flt",i,"sex",m,".png",sep="")
+                caption <- main
+                plotinfo <- pngfun(file=file, caption=caption)
+                persp(x,y,z,col="white",xlab=labels[2],ylab=labels[3],zlab=ylab,expand=0.5,box=TRUE,main=main,cex.main=cex.main,ticktype="detailed",phi=35,theta=-10)
+                dev.off()
+              }
+              if(12 %in% subplot){
+                file <- paste(plotdir,"sel12_timevary_contour_flt",i,"sex",m,".png",sep="")
+                caption <- main
+                plotinfo <- pngfun(file=file, caption=caption)
+                contour(x,y,z,nlevels=5,xlab=labels[2],main=main,cex.main=cex.main,col=ians_blues,lwd=lwd)
+                dev.off()
+              }
             }
-            if(12 %in% subplot){
-              file <- paste(plotdir,"sel12_timevary_contour_flt",i,"sex",m,".png",sep="")
-              caption <- main
-              plotinfo <- pngfun(file=file, caption=caption)
-              contour(x,y,z,nlevels=5,xlab=labels[2],main=main,cex.main=cex.main,col=ians_blues,lwd=lwd)
-              dev.off()
+            plotageselex2 <- plotageselex[plotageselex$year %in% c(max(as.numeric(plotageselex$year))),]
+            plotageselex2 <- plotageselex2[,-(1:7)]
+            main <- paste(sextitle2," year selectivity for ", fleetnames[i],sep="")
+            endselfunc <- function(){
+              if(!add) plot((as.numeric(names(plotageselex2))),(as.numeric(paste(c(plotageselex2)))),
+                            xlab=labels[2],ylim=c(0,1),main=main,cex.main=cex.main,ylab=ylab,
+                            type="n",col=col2,cex=1.1)
+              lines((as.numeric(names(plotageselex2))),(as.numeric(paste(c(plotageselex2)))),
+                    type="o",col=col2,cex=1.1)
+              abline(h=0,col="grey")
             }
-          }
-          plotageselex2 <- plotageselex[plotageselex$year %in% c(max(as.numeric(plotageselex$year))),]
-          plotageselex2 <- plotageselex2[,-(1:7)]
-          main <- paste(sextitle2," year selectivity for ", fleetnames[i],sep="")
-          endselfunc <- function()
-          {
-            if(!add) plot((as.numeric(names(plotageselex2))),(as.numeric(paste(c(plotageselex2)))),
-                          xlab=labels[2],ylim=c(0,1),main=main,cex.main=cex.main,ylab=ylab,
-                          type="n",col=col2,cex=1.1)
-            lines((as.numeric(names(plotageselex2))),(as.numeric(paste(c(plotageselex2)))),
-                  type="o",col=col2,cex=1.1)
-            abline(h=0,col="grey")
-          }
-          if(13 %in% subplot){
-            if(plot) endselfunc()
-            if(print)
-            {
-              file <- paste(plotdir,"sel13_age_flt",i,"sex",m,".png",sep="")
-              caption <- main
-              plotinfo <- pngfun(file=file, caption=caption)
-              endselfunc()
-              dev.off()
+            if(13 %in% subplot){
+              if(plot) endselfunc()
+              if(print){
+                file <- paste(plotdir,"sel13_age_flt",i,"sex",m,".png",sep="")
+                caption <- main
+                plotinfo <- pngfun(file=file, caption=caption)
+                endselfunc()
+                dev.off()
+              }
             }
           }
         }
-      }
-      if(!time)
-      {
-        plotageselex <- plotageselex[plotageselex$year==endyr,]
-        plotageselex <- plotageselex[,-(1:7)]
-        vals <- as.numeric(paste(c(plotageselex)))
-        doplot <- diff(range(vals))!=0
-        if(doplot & skipAgeSelex10) doplot <- !(vals[1]==0 & all(vals[-1]==1))
-#
-        if(doplot)
-        {
-          main <- paste(sextitle2," year selectivity for ", fleetnames[i],sep="")
-          endselfunc2 <- function(){
-            if(!add)
-              plot((as.numeric(names(plotageselex))),vals,xlab=labels[2],ylim=c(0,1),
-                   main=main,cex.main=cex.main,ylab=ylab,type="n")
-            lines((as.numeric(names(plotageselex))),vals,type="o",col=col2,cex=1.1)
-            abline(h=0,col="grey")
-          }
-          if(14 %in% subplot){
-            if(plot) endselfunc2()
-            if(print)
-            {
-              file <- paste(plotdir,"sel14_age_flt",i,"sex",m,".png",sep="")
-              caption <- main
-              plotinfo <- pngfun(file=file, caption=caption)
-              endselfunc2()
-              dev.off()
+        if(!time){
+          plotageselex <- plotageselex[plotageselex$year==endyr,]
+          plotageselex <- plotageselex[,-(1:7)]
+          vals <- as.numeric(paste(c(plotageselex)))
+          doplot <- diff(range(vals))!=0
+          if(doplot & skipAgeSelex10) doplot <- !(vals[1]==0 & all(vals[-1]==1))
+          #
+          if(doplot){
+            main <- paste(sextitle2," year selectivity for ", fleetnames[i],sep="")
+            endselfunc2 <- function(){
+              if(!add)
+                plot((as.numeric(names(plotageselex))),vals,xlab=labels[2],ylim=c(0,1),
+                     main=main,cex.main=cex.main,ylab=ylab,type="n")
+              lines((as.numeric(names(plotageselex))),vals,type="o",col=col2,cex=1.1)
+              abline(h=0,col="grey")
             }
-          }
-        } # end if
-      } # end if not time varying
-    } # sexes
-  } # fleets
-  flush.console()
-
+            if(14 %in% subplot){
+              if(plot) endselfunc2()
+              if(print){
+                file <- paste(plotdir,"sel14_age_flt",i,"sex",m,".png",sep="")
+                caption <- main
+                plotinfo <- pngfun(file=file, caption=caption)
+                endselfunc2()
+                dev.off()
+              }
+            }
+          } # end if
+        } # end if not time varying
+      } # sexes
+    } # fleets
+    flush.console()
+  } # factor (Asel vs. Asel2)
+  
   ################################################################################
   ### Selectivity contours over age and length shown with growth curve
   
@@ -625,14 +712,24 @@ SSplotSelex <-
     # Mid year mean length at age with 95% range of lengths (by sex if applicable)
     growdatF <- growdat[growdat$Gender==1 & growdat$Morph==mainmorphs[1],]
     growdatF$Sd_Size <- growdatF$SD_Mid
-    growdatF$high <- growdatF$Len_Mid + 1.96*growdatF$Sd_Size
-    growdatF$low <- growdatF$Len_Mid - 1.96*growdatF$Sd_Size
+    if(growthCVtype=="logSD=f(A)"){ # lognormal distribution of length at age
+      growdatF$high <- qlnorm(0.975, meanlog=log(growdatF$Len_Mid), sdlog=growdatF$Sd_Size)
+      growdatF$low  <- qlnorm(0.025, meanlog=log(growdatF$Len_Mid), sdlog=growdatF$Sd_Size)
+    }else{                        # normal distribution of length at age
+      growdatF$high <- qnorm(0.975, mean=growdatF$Len_Mid, sd=growdatF$Sd_Size)
+      growdatF$low  <- qnorm(0.025, mean=growdatF$Len_Mid, sd=growdatF$Sd_Size)
+    }
     if(nsexes > 1){
       growdatM <- growdat[growdat$Gender==2 & growdat$Morph==mainmorphs[2],]
       xm <- growdatM$Age
       growdatM$Sd_Size <- growdatM$SD_Mid
-      growdatM$high <- growdatM$Len_Mid + 1.96*growdatM$Sd_Size
-      growdatM$low <- growdatM$Len_Mid - 1.96*growdatM$Sd_Size
+      if(growthCVtype=="logSD=f(A)"){ # lognormal distribution of length at age
+        growdatM$high <- qlnorm(0.975, meanlog=log(growdatM$Len_Mid), sdlog=growdatM$Sd_Size)
+        growdatM$low  <- qlnorm(0.025, meanlog=log(growdatM$Len_Mid), sdlog=growdatM$Sd_Size)
+      }else{                        # normal distribution of length at age
+        growdatM$high <- qnorm(0.975, mean=growdatM$Len_Mid, sd=growdatM$Sd_Size)
+        growdatM$low  <- qnorm(0.025, mean=growdatM$Len_Mid, sd=growdatM$Sd_Size)
+      }
     }
 
     xlab <- labels[2]
@@ -712,7 +809,8 @@ SSplotSelex <-
       i <- sel$fleet[1]
       agelen <- sel$agelen[1]
       xlab <- labels[1:2][1 + (sel$agelen[1]=="A")] # decide label between length and age
-      for(m in unique(sel$sex)){
+
+      for(m in intersect(unique(sel$sex),c("Fem","Mal")[sexes])){
         seltemp <- sel[sel$sex==m,]
         if(m=="Fem" & nsexes==1) sextitle3 <- ""
         if(m=="Fem" & nsexes==2) sextitle3 <- "females"
@@ -749,5 +847,5 @@ SSplotSelex <-
     } # end test for presence of selectivity uncertainty output
   } # check check for subplot in list
   if(!is.null(plotinfo)) plotinfo$category <- "Sel"
-  return(invisible(list(infotable=infotable,plotinfo=plotinfo)))
+  return(invisible(list(infotable=infotable2,plotinfo=plotinfo)))
 } 
