@@ -1,13 +1,106 @@
+#' Create multi-figure plots.
+#' 
+#' Function created as an alternative to lattice package for multi-figure plots
+#' of composition data and fits from Stock Synthesis output.
+#' 
+#' 
+#' @param ptsx vector of x values for points or bars
+#' @param ptsy vector of y values for points or bars of same length as ptsx
+#' @param yr vector of category values (years) of same length as ptsx
+#' @param linesx optional vector of x values for lines
+#' @param linesy optional vector of y values for lines
+#' @param ptsSD optional vector of standard deviations used to plot error bars
+#' on top of each point under the assumption of normally distributed error
+#' @param sampsize optional sample size vector of same length as ptsx
+#' @param effN optional effective sample size vector of same length as ptsx
+#' @param showsampsize show sample size values on plot?
+#' @param showeffN show effective sample size values on plot?
+#' @param sampsizeround rounding level for sample size values
+#' @param maxrows maximum (or fixed) number or rows of panels in the plot
+#' @param maxcols maximum (or fixed) number or columns of panels in the plot
+#' @param rows number or rows to return to as default for next plots to come or
+#' for single plots
+#' @param cols number or cols to return to as default for next plots to come or
+#' for single plots
+#' @param fixdims fix the dimensions at maxrows by maxcols or resize based on
+#' number of elements in \code{yr} input.
+#' @param main title of plot
+#' @param cex.main character expansion for title
+#' @param xlab x-axis label
+#' @param ylab y-axis label
+#' @param size vector of bubbles sizes if making a bubble plot
+#' @param cexZ1 Character expansion (cex) for point associated with value of 1.
+#' @param bublegend Add legend with example bubble sizes to bubble plots.
+#' @param maxsize maximum size of bubbles
+#' @param do.sqrt scale bubbles based on sqrt of size vector. see ?bubble3 for
+#' more info.
+#' @param minnbubble number of unique x values before adding buffer. see
+#' ?bubble3 for more info.
+#' @param allopen should all bubbles be open? see ?bubble3 for more info.
+#' @param horiz_lab axis labels set horizontal all the time (TRUE), never
+#' (FALSE) or only when relatively short ("default")
+#' @param xbuffer extra space around points on the left and right as fraction
+#' of total width of plot
+#' @param ybuffer like xbuffer
+#' @param ymin0 fix minimum y-value at 0?
+#' @param axis1 position of bottom axis values
+#' @param axis2 position of left size axis values
+#' @param linepos should lines be added on top of points (linepos=1) or behind
+#' (linepos=2)?
+#' @param type type of line/points used for observed values (see 'type' in
+#' ?plot for details) on top of a grey polygon. Default is "o" for overplotting
+#' points on lines.
+#' @param bars should the ptsx/ptsy values be bars instead of points
+#' (TRUE/FALSE)
+#' @param barwidth width of bars in barplot, default method chooses based on
+#' quick and dirty formula also, current method of plot(...type='h') could be
+#' replaced with better approach
+#' @param ptscex character expansion factor for points (default=1)
+#' @param ptscol color for points/bars
+#' @param ptscol2 color for negative value points in bubble plots
+#' @param linescol color for lines
+#' @param lty line type
+#' @param lwd line width
+#' @param pch point character type
+#' @param nlegends number of lines of text to add as legends in each plot
+#' @param legtext text in legend, a list of length=nlegends. values may be any
+#' of 1.  "yr", 2. "sampsize", 3. "effN", or a vector of length = ptsx.
+#' @param legx vector of length=nlegends of x-values of legends (default is
+#' first one on left, all after on right)
+#' @param legy vector of length=nlegends of y-values of legends (default is top
+#' for all plots)
+#' @param legadjx left/right adjustment of legends around legx
+#' @param legadjy left/right adjustment of legends around legy
+#' @param legsize font size for legends. default=c(1.2,1.0) (larger for year
+#' and normal for others)
+#' @param legfont font type for legends, same as "font" under ?par
+#' @param sampsizeline show line for input sample sizes on top of conditional
+#' age-at-length plots (TRUE/FALSE/scalar, still in development)
+#' @param effNline show line for effective sample sizes on top of conditional
+#' age-at-length plots (TRUE/FALSE/scalar, still in development)
+#' @param sampsizemean mean input sample size value (used when sampsizeline=TRUE)
+#' @param effNmean mean effective sample size value (used when effNline=TRUE)
+#' @param ipage which page of plots when covering more than will fit within
+#' maxrows by maxcols.
+#' @param scalebins Rescale expected and observed proportions by dividing by
+#' bin width for models where bins have different widths? Caution!: May not
+#' work correctly in all cases.
+#' @param \dots additional arguments (NOT YET IMPLEMENTED).
+#' @author Ian Taylor
+#' @seealso \code{\link{SS_plots}},\code{\link{SSplotComps}}
+#' @keywords aplot hplot
 make_multifig <- function(ptsx, ptsy, yr, linesx=0, linesy=0, ptsSD=0,
                           sampsize=0, effN=0, showsampsize=TRUE, showeffN=TRUE, sampsizeround=1,
                           maxrows=6, maxcols=6, rows=1, cols=1, fixdims=TRUE, main="",cex.main=1,
-                          xlab="",ylab="",size=1,maxsize=3,do.sqrt=TRUE,minnbubble=8,allopen=TRUE,
+                          xlab="",ylab="",size=1,cexZ1=1.5,bublegend=TRUE,
+                          maxsize=NULL,do.sqrt=TRUE,minnbubble=8,allopen=TRUE,
                           horiz_lab="default",xbuffer=c(.1,.1),ybuffer=c(0,0.15),ymin0=TRUE,
                           axis1="default",axis2="default",linepos=1,type="o",
                           bars=FALSE,barwidth="default",ptscex=1,ptscol=1,ptscol2=1,linescol=2,lty=1,lwd=1,pch=1,
                           nlegends=3,legtext=list("yr","sampsize","effN"),legx="default",legy="default",
                           legadjx="default",legadjy="default",legsize=c(1.2,1.0),legfont=c(2,1),
-                          ipage=0,scalebins=FALSE){
+                          sampsizeline=FALSE,effNline=FALSE,sampsizemean=NULL,effNmean=NULL,
+                          ipage=0,scalebins=FALSE,...){
   ################################################################################
   #
   # make_multifig
@@ -17,29 +110,6 @@ make_multifig <- function(ptsx, ptsy, yr, linesx=0, linesy=0, ptsSD=0,
   # Written: Ian Taylor
   #
   ################################################################################
-  bubble3 <- function (x,y,z,col=c(1,1),maxsize=3,do.sqrt=TRUE,
-                       main="",cex.main=1,xlab="",ylab="",minnbubble=8,
-                       xlimextra=1,add=FALSE,las=1,allopen=TRUE){
-    # vaguely based on bubble() from gstat
-    az <- abs(z)
-    if (do.sqrt) az <- sqrt(az)
-    cex <- maxsize * az/max(az)
-    z.col <- ifelse(z < 0, col[1], col[2])
-    xlim <- range(x)
-    if(length(unique(x))<minnbubble) xlim=xlim+c(-1,1)*xlimextra
-    pch <- z
-    pch[pch==0] <- NA
-    pch[pch>0] <- 16
-    pch[pch<0] <- 1
-    if(allopen) pch[!is.na(pch)] <- 1
-    if(!add){
-      plot(x,y,type="n",xlim=xlim,main=main,cex.main=cex.main,xlab=xlab,ylab=ylab,axes=FALSE,cex.main=cex.main)
-      axis(1,at=unique(x))
-      axis(2,las=las)
-      box()
-    }
-    points(x,y,pch=pch,cex=cex,col=z.col)
-  }
 
   # define dimensions
   yrvec <- sort(unique(yr))
@@ -135,9 +205,30 @@ make_multifig <- function(ptsx, ptsy, yr, linesx=0, linesy=0, ptsSD=0,
          xaxs="i",yaxs=ifelse(bars,"i","r"))
     abline(h=0,col="grey") # grey line at 0
     if(linepos==2) lines(linesx_i,linesy_i,col=linescol,lwd=lwd,lty=lty) # lines first
-    if(diff(range(size))!=0){ # if size input is provided then use bubble function
-      bubble3(x=ptsx_i,y=ptsy_i,z=z_i,col=c(ptscol,ptscol2),
+    if(diff(range(size,na.rm=TRUE))!=0){ # if size input is provided then use bubble function
+      bubble3(x=ptsx_i,y=ptsy_i,z=z_i,col=ptscol,cexZ1=cexZ1,legend.yadj=1.5,
+              legend=bublegend,legendloc='topright',
               maxsize=maxsize,minnbubble=minnbubble,allopen=allopen,add=TRUE) # bubble plot
+      # add optional lines showing (adjusted) input sample size
+      if(linepos==0) effNline <- 0
+      if(effNline>0 && length(effN)>0){
+        effN_i         <- effN[yr==yr_i]
+        effN_i_vec     <- unlist(lapply(split(effN_i,ptsy_i),unique))
+        ptsy_i_vec     <- sort(unique(ptsy_i))
+        lines(effNline*effN_i_vec,ptsy_i_vec,col='green3')
+        if(!is.null(effNmean))
+          lines(rep(effNline*effNmean,length(ptsy_i_vec)),ptsy_i_vec,col='green3',lty=2)
+      }
+      # add optional lines showing effective sample size 
+      if(sampsizeline>0 && length(sampsize)>0){
+        sampsize_i     <- sampsize[yr==yr_i]
+        sampsize_i_vec <- unlist(lapply(split(sampsize_i,ptsy_i),unique))
+        ptsy_i_vec     <- sort(unique(ptsy_i))
+
+        lines(sampsizeline*sampsize_i_vec,ptsy_i_vec,col=2)
+        if(!is.null(sampsizemean))
+          lines(rep(sampsizeline*sampsizemean,length(ptsy_i_vec)),ptsy_i_vec,col=2,lty=3)
+      }
     }else{
       if(FALSE){
         # turning off old way
